@@ -2,6 +2,7 @@
 dataprep.clean
 ==============
 """
+
 from .clean_lat_long import clean_lat_long, validate_lat_long
 
 from .clean_email import clean_email, validate_email
@@ -10,6 +11,8 @@ from .clean_country import clean_country, validate_country
 
 from .clean_url import clean_url, validate_url
 
+from .clean_json import clean_json, validate_json
+
 from .clean_phone import clean_phone, validate_phone
 
 from .clean_ip import clean_ip, validate_ip
@@ -367,6 +370,8 @@ __all__ = [
     "validate_url",
     "clean_phone",
     "validate_phone",
+    "clean_json",
+    "validate_json",
     "clean_ip",
     "validate_ip",
     "clean_headers",
