@@ -1,6 +1,6 @@
 import Vue from 'vue'
 import Router from 'vue-router'
-import Table from '@/components/Table'
+import SampleDF from '../components/SampleDF'
 
 Vue.use(Router)
 
@@ -8,8 +8,8 @@ export default new Router({
   routes: [
     {
       path: '/',
-      name: 'Table',
-      component: Table
+      name: 'SampleDF',
+      component: SampleDF
     }
   ]
 })
