@@ -4,7 +4,8 @@ from typing import Any, Dict, Optional
 
 from .connector import Connector
 from .generator import ConfigGenerator, ConfigGeneratorUI
-from .info import info
+from .info import info, websites
+from .sql import read_sql
 
 __all__ = [
     "Connector",
@@ -12,6 +13,8 @@ __all__ = [
     "ConfigGeneratorUI",
     "connect",
     "info",
+    "websites",
+    "read_sql",
 ]
 
 
