@@ -1267,14 +1267,14 @@ def dt_line_viz(
     Render a line chart
     """
     # pylint: disable=too-many-arguments
+    agg = "freq" if miss_pct is not None else f"{df.columns[1]}"
+    title_agg = agg if agg != "runningtotal" else "running total"
     if miss_pct is not None:
         title = f"{x} ({miss_pct}% missing)" if miss_pct > 0 else f"{x}"
         tooltips = [(timeunit, "@lbl"), ("Frequency", "@freq"), ("Percent", "@pct%")]
-        agg = "freq"
     else:
-        title = title = f"{df.columns[1]} of {y} by {x}"
-        agg = f"{df.columns[1]}"
-        tooltips = [(timeunit, "@lbl"), (agg, f"@{df.columns[1]}")]
+        title = f"{title_agg} of {y} by {x}"
+        tooltips = [(timeunit, "@lbl"), (title_agg, f"@{df.columns[1]}")]
     fig = Figure(
         plot_width=plot_width,
         plot_height=plot_height,
@@ -1303,9 +1303,10 @@ def dt_line_viz(
         _format_axis(fig, 0, df[agg].max(), "y")
 
     if y:
-        fig.yaxis.axis_label = f"{df.columns[1]} of {y}"
+        fig.yaxis.axis_label = f"{title_agg} of {y}"
         fig.xaxis.axis_label = x
-        return Panel(child=fig, title="Line Chart")
+        cap_agg = title_agg.title()
+        return Panel(child=fig, title=f"Line Chart ({cap_agg})")
 
     fig.yaxis.axis_label = "Frequency"
     return fig
@@ -2331,10 +2332,10 @@ def render_dt_num(itmdt: Intermediate, cfg: Config) -> Dict[str, Any]:
 
     tabs: List[Panel] = []
     if cfg.line.enable:
-        linedf, timeunit = itmdt["linedata"]
+        linedf_agg, timeunit = itmdt["linedata_agg"]
         tabs.append(
             dt_line_viz(
-                linedf,
+                linedf_agg,
                 itmdt["x"],
                 timeunit,
                 cfg.line.yscale,
@@ -2344,6 +2345,21 @@ def render_dt_num(itmdt: Intermediate, cfg: Config) -> Dict[str, Any]:
                 y=itmdt["y"],
             )
         )
+
+        linedf_running_total, timeunit = itmdt["linedata_running_total"]
+        tabs.append(
+            dt_line_viz(
+                linedf_running_total,
+                itmdt["x"],
+                timeunit,
+                cfg.line.yscale,
+                plot_width,
+                plot_height,
+                True,
+                y=itmdt["y"],
+            )
+        )
+
     if cfg.box.enable:
         boxdf, outx, outy, timeunit = itmdt["boxdata"]
         tabs.append(
@@ -2442,7 +2458,6 @@ def render_dt_num_cat(itmdt: Intermediate, cfg: Config) -> Dict[str, Any]:
 def render(itmdt: Intermediate, cfg: Config) -> Union[LayoutDOM, Dict[str, Any]]:
     """
     Render a basic plot
-
     Parameters
     ----------
     itmdt
